
function [int,h] = trapezi (f,a,b,m)
%TRAPEZI Metodo dei Trapezi composto
%
% [int,h] = trapezi (f,a,b,m);
%
% Dati di ingresso:
% f: funzione integranda
% a: estremo sinistro dell'intervallo di integrazione
% b: estremo destro dell'intervallo di integrazione
% m: numero di sottointervalli
%
% Dati di uscita:
% int: approssimazione dell'integrale definito
% h: passo di integrazione

h=(b-a)/m;
x=linspace(a,b,m); x=x';
w=h*ones(size(x)); w(1)=w(1)/2; w(end)=w(end)/2;
fx=feval(f,x);
int=w'*fx;
